# tf_helpers
A collection of useful functions for TensorFlow for training and visualization.

Written in TensorFlow.

## Installation
Python Versions from 3.5+ are supported.
Install from PyPi with `pip install tf_helpers`.
`tf_helpers` requires TensorFlow.
If you want it to be installed automatically choose between the CPU and GPU version 
with `pip install tf_helpers[tf]` or `pip install tf_helpers[tf_gpu]` respectively.

## Examples
TODO
